# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: accelbyte_cloud_py_codegen

# AccelByte Cloud Platform Service (4.15.0)

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model
from ....core import StrEnum

from ..models.import_error_details import ImportErrorDetails
from ..models.import_store_item_info import ImportStoreItemInfo


class TypeEnum(StrEnum):
    ITEM = "ITEM"


class ImportStoreError(Model):
    """Import store error (ImportStoreError)

    Properties:
        errors: (errors) OPTIONAL List[ImportErrorDetails]

        item: (item) OPTIONAL ImportStoreItemInfo

        type_: (type) OPTIONAL Union[str, TypeEnum]
    """

    # region fields

    errors: List[ImportErrorDetails]  # OPTIONAL
    item: ImportStoreItemInfo  # OPTIONAL
    type_: Union[str, TypeEnum]  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_errors(self, value: List[ImportErrorDetails]) -> ImportStoreError:
        self.errors = value
        return self

    def with_item(self, value: ImportStoreItemInfo) -> ImportStoreError:
        self.item = value
        return self

    def with_type(self, value: Union[str, TypeEnum]) -> ImportStoreError:
        self.type_ = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "errors"):
            result["errors"] = [
                i0.to_dict(include_empty=include_empty) for i0 in self.errors
            ]
        elif include_empty:
            result["errors"] = []
        if hasattr(self, "item"):
            result["item"] = self.item.to_dict(include_empty=include_empty)
        elif include_empty:
            result["item"] = ImportStoreItemInfo()
        if hasattr(self, "type_"):
            result["type"] = str(self.type_)
        elif include_empty:
            result["type"] = Union[str, TypeEnum]()
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        errors: Optional[List[ImportErrorDetails]] = None,
        item: Optional[ImportStoreItemInfo] = None,
        type_: Optional[Union[str, TypeEnum]] = None,
    ) -> ImportStoreError:
        instance = cls()
        if errors is not None:
            instance.errors = errors
        if item is not None:
            instance.item = item
        if type_ is not None:
            instance.type_ = type_
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ImportStoreError:
        instance = cls()
        if not dict_:
            return instance
        if "errors" in dict_ and dict_["errors"] is not None:
            instance.errors = [
                ImportErrorDetails.create_from_dict(i0, include_empty=include_empty)
                for i0 in dict_["errors"]
            ]
        elif include_empty:
            instance.errors = []
        if "item" in dict_ and dict_["item"] is not None:
            instance.item = ImportStoreItemInfo.create_from_dict(
                dict_["item"], include_empty=include_empty
            )
        elif include_empty:
            instance.item = ImportStoreItemInfo()
        if "type" in dict_ and dict_["type"] is not None:
            instance.type_ = str(dict_["type"])
        elif include_empty:
            instance.type_ = Union[str, TypeEnum]()
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ImportStoreError]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ImportStoreError]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[ImportStoreError, List[ImportStoreError], Dict[Any, ImportStoreError]]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "errors": "errors",
            "item": "item",
            "type": "type_",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "errors": False,
            "item": False,
            "type": False,
        }

    @staticmethod
    def get_enum_map() -> Dict[str, List[Any]]:
        return {
            "type": ["ITEM"],
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: accelbyte_cloud_py_codegen

# AccelByte Cloud Qo S Manager Service ()

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model


class ModelsServer(Model):
    """Models server (models.Server)

    Properties:
        alias: (alias) REQUIRED str

        ip: (ip) REQUIRED str

        last_update: (last_update) REQUIRED str

        port: (port) REQUIRED int

        region: (region) REQUIRED str

        status: (status) REQUIRED str
    """

    # region fields

    alias: str  # REQUIRED
    ip: str  # REQUIRED
    last_update: str  # REQUIRED
    port: int  # REQUIRED
    region: str  # REQUIRED
    status: str  # REQUIRED

    # endregion fields

    # region with_x methods

    def with_alias(self, value: str) -> ModelsServer:
        self.alias = value
        return self

    def with_ip(self, value: str) -> ModelsServer:
        self.ip = value
        return self

    def with_last_update(self, value: str) -> ModelsServer:
        self.last_update = value
        return self

    def with_port(self, value: int) -> ModelsServer:
        self.port = value
        return self

    def with_region(self, value: str) -> ModelsServer:
        self.region = value
        return self

    def with_status(self, value: str) -> ModelsServer:
        self.status = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "alias"):
            result["alias"] = str(self.alias)
        elif include_empty:
            result["alias"] = ""
        if hasattr(self, "ip"):
            result["ip"] = str(self.ip)
        elif include_empty:
            result["ip"] = ""
        if hasattr(self, "last_update"):
            result["last_update"] = str(self.last_update)
        elif include_empty:
            result["last_update"] = ""
        if hasattr(self, "port"):
            result["port"] = int(self.port)
        elif include_empty:
            result["port"] = 0
        if hasattr(self, "region"):
            result["region"] = str(self.region)
        elif include_empty:
            result["region"] = ""
        if hasattr(self, "status"):
            result["status"] = str(self.status)
        elif include_empty:
            result["status"] = ""
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        alias: str,
        ip: str,
        last_update: str,
        port: int,
        region: str,
        status: str,
    ) -> ModelsServer:
        instance = cls()
        instance.alias = alias
        instance.ip = ip
        instance.last_update = last_update
        instance.port = port
        instance.region = region
        instance.status = status
        return instance

    @classmethod
    def create_from_dict(cls, dict_: dict, include_empty: bool = False) -> ModelsServer:
        instance = cls()
        if not dict_:
            return instance
        if "alias" in dict_ and dict_["alias"] is not None:
            instance.alias = str(dict_["alias"])
        elif include_empty:
            instance.alias = ""
        if "ip" in dict_ and dict_["ip"] is not None:
            instance.ip = str(dict_["ip"])
        elif include_empty:
            instance.ip = ""
        if "last_update" in dict_ and dict_["last_update"] is not None:
            instance.last_update = str(dict_["last_update"])
        elif include_empty:
            instance.last_update = ""
        if "port" in dict_ and dict_["port"] is not None:
            instance.port = int(dict_["port"])
        elif include_empty:
            instance.port = 0
        if "region" in dict_ and dict_["region"] is not None:
            instance.region = str(dict_["region"])
        elif include_empty:
            instance.region = ""
        if "status" in dict_ and dict_["status"] is not None:
            instance.status = str(dict_["status"])
        elif include_empty:
            instance.status = ""
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ModelsServer]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ModelsServer]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[ModelsServer, List[ModelsServer], Dict[Any, ModelsServer]]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "alias": "alias",
            "ip": "ip",
            "last_update": "last_update",
            "port": "port",
            "region": "region",
            "status": "status",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "alias": True,
            "ip": True,
            "last_update": True,
            "port": True,
            "region": True,
            "status": True,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: accelbyte_cloud_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import HeaderStr
from ....core import get_namespace as get_services_namespace
from ....core import run_request
from ....core import run_request_async
from ....core import same_doc_as

from ..models import ModelsDeleteBulkLeaderboardsReq
from ..models import ModelsDeleteBulkLeaderboardsResp
from ..models import ModelsGetAllLeaderboardConfigsPublicResp
from ..models import ModelsGetAllLeaderboardConfigsResp
from ..models import ModelsGetLeaderboardConfigResp
from ..models import ModelsLeaderboardConfigReq
from ..models import ModelsUpdateLeaderboardConfigReq
from ..models import ResponseErrorResponse
from ..models import V2GetAllLeaderboardConfigsPublicResp

from ..operations.leaderboard_configuration import CreateLeaderboardConfigurationAdminV1
from ..operations.leaderboard_configuration import (
    CreateLeaderboardConfigurationPublicV1,
)
from ..operations.leaderboard_configuration import (
    DeleteBulkLeaderboardConfigurationAdminV1,
)
from ..operations.leaderboard_configuration import DeleteLeaderboardConfigurationAdminV1
from ..operations.leaderboard_configuration import GetLeaderboardConfigurationAdminV1
from ..operations.leaderboard_configuration import GetLeaderboardConfigurationsAdminV1
from ..operations.leaderboard_configuration import GetLeaderboardConfigurationsPublicV1
from ..operations.leaderboard_configuration import GetLeaderboardConfigurationsPublicV2
from ..operations.leaderboard_configuration import UpdateLeaderboardConfigurationAdminV1


@same_doc_as(CreateLeaderboardConfigurationAdminV1)
def create_leaderboard_configuration_admin_v1(
    body: ModelsLeaderboardConfigReq,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = CreateLeaderboardConfigurationAdminV1.create(
        body=body,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(CreateLeaderboardConfigurationAdminV1)
async def create_leaderboard_configuration_admin_v1_async(
    body: ModelsLeaderboardConfigReq,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = CreateLeaderboardConfigurationAdminV1.create(
        body=body,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(CreateLeaderboardConfigurationPublicV1)
def create_leaderboard_configuration_public_v1(
    body: ModelsLeaderboardConfigReq,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = CreateLeaderboardConfigurationPublicV1.create(
        body=body,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(CreateLeaderboardConfigurationPublicV1)
async def create_leaderboard_configuration_public_v1_async(
    body: ModelsLeaderboardConfigReq,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = CreateLeaderboardConfigurationPublicV1.create(
        body=body,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(DeleteBulkLeaderboardConfigurationAdminV1)
def delete_bulk_leaderboard_configuration_admin_v1(
    body: ModelsDeleteBulkLeaderboardsReq,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = DeleteBulkLeaderboardConfigurationAdminV1.create(
        body=body,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(DeleteBulkLeaderboardConfigurationAdminV1)
async def delete_bulk_leaderboard_configuration_admin_v1_async(
    body: ModelsDeleteBulkLeaderboardsReq,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = DeleteBulkLeaderboardConfigurationAdminV1.create(
        body=body,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(DeleteLeaderboardConfigurationAdminV1)
def delete_leaderboard_configuration_admin_v1(
    leaderboard_code: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = DeleteLeaderboardConfigurationAdminV1.create(
        leaderboard_code=leaderboard_code,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(DeleteLeaderboardConfigurationAdminV1)
async def delete_leaderboard_configuration_admin_v1_async(
    leaderboard_code: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = DeleteLeaderboardConfigurationAdminV1.create(
        leaderboard_code=leaderboard_code,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(GetLeaderboardConfigurationAdminV1)
def get_leaderboard_configuration_admin_v1(
    leaderboard_code: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetLeaderboardConfigurationAdminV1.create(
        leaderboard_code=leaderboard_code,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GetLeaderboardConfigurationAdminV1)
async def get_leaderboard_configuration_admin_v1_async(
    leaderboard_code: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetLeaderboardConfigurationAdminV1.create(
        leaderboard_code=leaderboard_code,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(GetLeaderboardConfigurationsAdminV1)
def get_leaderboard_configurations_admin_v1(
    is_archived: Optional[bool] = None,
    is_deleted: Optional[bool] = None,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetLeaderboardConfigurationsAdminV1.create(
        is_archived=is_archived,
        is_deleted=is_deleted,
        limit=limit,
        offset=offset,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GetLeaderboardConfigurationsAdminV1)
async def get_leaderboard_configurations_admin_v1_async(
    is_archived: Optional[bool] = None,
    is_deleted: Optional[bool] = None,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetLeaderboardConfigurationsAdminV1.create(
        is_archived=is_archived,
        is_deleted=is_deleted,
        limit=limit,
        offset=offset,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(GetLeaderboardConfigurationsPublicV1)
def get_leaderboard_configurations_public_v1(
    is_archived: Optional[bool] = None,
    is_deleted: Optional[bool] = None,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetLeaderboardConfigurationsPublicV1.create(
        is_archived=is_archived,
        is_deleted=is_deleted,
        limit=limit,
        offset=offset,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GetLeaderboardConfigurationsPublicV1)
async def get_leaderboard_configurations_public_v1_async(
    is_archived: Optional[bool] = None,
    is_deleted: Optional[bool] = None,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetLeaderboardConfigurationsPublicV1.create(
        is_archived=is_archived,
        is_deleted=is_deleted,
        limit=limit,
        offset=offset,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(GetLeaderboardConfigurationsPublicV2)
def get_leaderboard_configurations_public_v2(
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetLeaderboardConfigurationsPublicV2.create(
        limit=limit,
        offset=offset,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GetLeaderboardConfigurationsPublicV2)
async def get_leaderboard_configurations_public_v2_async(
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetLeaderboardConfigurationsPublicV2.create(
        limit=limit,
        offset=offset,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(UpdateLeaderboardConfigurationAdminV1)
def update_leaderboard_configuration_admin_v1(
    body: ModelsUpdateLeaderboardConfigReq,
    leaderboard_code: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = UpdateLeaderboardConfigurationAdminV1.create(
        body=body,
        leaderboard_code=leaderboard_code,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(UpdateLeaderboardConfigurationAdminV1)
async def update_leaderboard_configuration_admin_v1_async(
    body: ModelsUpdateLeaderboardConfigReq,
    leaderboard_code: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = UpdateLeaderboardConfigurationAdminV1.create(
        body=body,
        leaderboard_code=leaderboard_code,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: accelbyte_cloud_py_codegen

"""Auto-generated package that contains models used by the AccelByte Cloud Platform Service."""

__version__ = "4.15.0"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .anonymize_campaign import AnonymizeCampaign
from .anonymize_entitlement import AnonymizeEntitlement
from .anonymize_fulfillment import AnonymizeFulfillment
from .anonymize_integration import AnonymizeIntegration
from .anonymize_order import AnonymizeOrder
from .anonymize_payment import AnonymizePayment
from .anonymize_subscription import AnonymizeSubscription
from .anonymize_wallet import AnonymizeWallet



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: accelbyte_cloud_py_codegen

# AccelByte Cloud Platform Service (4.15.0)

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model
from ....core import StrEnum

from ..models.available_comparison_object import AvailableComparisonObject


class PredicateTypeEnum(StrEnum):
    ENTITLEMENTPREDICATE = "EntitlementPredicate"
    SEASONPASSPREDICATE = "SeasonPassPredicate"
    SEASONTIERPREDICATE = "SeasonTierPredicate"


class ValueTypeEnum(StrEnum):
    LIST = "List"
    NUMBER = "Number"
    STRING = "String"


class AvailablePredicateObject(Model):
    """Available predicate object (available predicate object)

    Properties:
        available_comparisons: (availableComparisons) OPTIONAL List[AvailableComparisonObject]

        predicate_type: (predicateType) OPTIONAL Union[str, PredicateTypeEnum]

        show_any_of: (showAnyOf) OPTIONAL bool

        value_type: (valueType) OPTIONAL Union[str, ValueTypeEnum]
    """

    # region fields

    available_comparisons: List[AvailableComparisonObject]  # OPTIONAL
    predicate_type: Union[str, PredicateTypeEnum]  # OPTIONAL
    show_any_of: bool  # OPTIONAL
    value_type: Union[str, ValueTypeEnum]  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_available_comparisons(
        self, value: List[AvailableComparisonObject]
    ) -> AvailablePredicateObject:
        self.available_comparisons = value
        return self

    def with_predicate_type(
        self, value: Union[str, PredicateTypeEnum]
    ) -> AvailablePredicateObject:
        self.predicate_type = value
        return self

    def with_show_any_of(self, value: bool) -> AvailablePredicateObject:
        self.show_any_of = value
        return self

    def with_value_type(
        self, value: Union[str, ValueTypeEnum]
    ) -> AvailablePredicateObject:
        self.value_type = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "available_comparisons"):
            result["availableComparisons"] = [
                i0.to_dict(include_empty=include_empty)
                for i0 in self.available_comparisons
            ]
        elif include_empty:
            result["availableComparisons"] = []
        if hasattr(self, "predicate_type"):
            result["predicateType"] = str(self.predicate_type)
        elif include_empty:
            result["predicateType"] = Union[str, PredicateTypeEnum]()
        if hasattr(self, "show_any_of"):
            result["showAnyOf"] = bool(self.show_any_of)
        elif include_empty:
            result["showAnyOf"] = False
        if hasattr(self, "value_type"):
            result["valueType"] = str(self.value_type)
        elif include_empty:
            result["valueType"] = Union[str, ValueTypeEnum]()
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        available_comparisons: Optional[List[AvailableComparisonObject]] = None,
        predicate_type: Optional[Union[str, PredicateTypeEnum]] = None,
        show_any_of: Optional[bool] = None,
        value_type: Optional[Union[str, ValueTypeEnum]] = None,
    ) -> AvailablePredicateObject:
        instance = cls()
        if available_comparisons is not None:
            instance.available_comparisons = available_comparisons
        if predicate_type is not None:
            instance.predicate_type = predicate_type
        if show_any_of is not None:
            instance.show_any_of = show_any_of
        if value_type is not None:
            instance.value_type = value_type
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> AvailablePredicateObject:
        instance = cls()
        if not dict_:
            return instance
        if (
            "availableComparisons" in dict_
            and dict_["availableComparisons"] is not None
        ):
            instance.available_comparisons = [
                AvailableComparisonObject.create_from_dict(
                    i0, include_empty=include_empty
                )
                for i0 in dict_["availableComparisons"]
            ]
        elif include_empty:
            instance.available_comparisons = []
        if "predicateType" in dict_ and dict_["predicateType"] is not None:
            instance.predicate_type = str(dict_["predicateType"])
        elif include_empty:
            instance.predicate_type = Union[str, PredicateTypeEnum]()
        if "showAnyOf" in dict_ and dict_["showAnyOf"] is not None:
            instance.show_any_of = bool(dict_["showAnyOf"])
        elif include_empty:
            instance.show_any_of = False
        if "valueType" in dict_ and dict_["valueType"] is not None:
            instance.value_type = str(dict_["valueType"])
        elif include_empty:
            instance.value_type = Union[str, ValueTypeEnum]()
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, AvailablePredicateObject]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[AvailablePredicateObject]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        AvailablePredicateObject,
        List[AvailablePredicateObject],
        Dict[Any, AvailablePredicateObject],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "availableComparisons": "available_comparisons",
            "predicateType": "predicate_type",
            "showAnyOf": "show_any_of",
            "valueType": "value_type",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "availableComparisons": False,
            "predicateType": False,
            "showAnyOf": False,
            "valueType": False,
        }

    @staticmethod
    def get_enum_map() -> Dict[str, List[Any]]:
        return {
            "predicateType": [
                "EntitlementPredicate",
                "SeasonPassPredicate",
                "SeasonTierPredicate",
            ],
            "valueType": ["List", "Number", "String"],
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: accelbyte_cloud_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import HeaderStr
from ....core import get_namespace as get_services_namespace
from ....core import run_request
from ....core import run_request_async
from ....core import same_doc_as

from ..models import ModelsAdminAddProfanityFilterIntoListRequest
from ..models import ModelsAdminAddProfanityFiltersRequest
from ..models import ModelsAdminCreateProfanityListRequest
from ..models import ModelsAdminDeleteProfanityFilterRequest
from ..models import ModelsAdminGetProfanityListFiltersV1Response
from ..models import ModelsAdminGetProfanityListsListResponse
from ..models import ModelsAdminSetProfanityRuleForNamespaceRequest
from ..models import ModelsAdminUpdateProfanityList
from ..models import ModelsAdminVerifyMessageProfanityRequest
from ..models import ModelsAdminVerifyMessageProfanityResponse
from ..models import ModelsDebugProfanityFilterRequest
from ..models import ModelsProfanityFilter
from ..models import ModelsProfanityRule
from ..models import RestapiErrorResponseBody

from ..operations.profanity import AdminAddProfanityFilterIntoList
from ..operations.profanity import AdminAddProfanityFilters
from ..operations.profanity import AdminCreateProfanityList
from ..operations.profanity import AdminDebugProfanityFilters
from ..operations.profanity import AdminDeleteProfanityFilter
from ..operations.profanity import AdminDeleteProfanityList
from ..operations.profanity import AdminGetProfanityListFiltersV1
from ..operations.profanity import AdminGetProfanityLists
from ..operations.profanity import AdminGetProfanityRule
from ..operations.profanity import AdminImportProfanityFiltersFromFile
from ..operations.profanity import AdminSetProfanityRuleForNamespace
from ..operations.profanity import AdminUpdateProfanityList
from ..operations.profanity import AdminVerifyMessageProfanityResponse


@same_doc_as(AdminAddProfanityFilterIntoList)
def admin_add_profanity_filter_into_list(
    body: ModelsAdminAddProfanityFilterIntoListRequest,
    list_: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminAddProfanityFilterIntoList.create(
        body=body,
        list_=list_,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminAddProfanityFilterIntoList)
async def admin_add_profanity_filter_into_list_async(
    body: ModelsAdminAddProfanityFilterIntoListRequest,
    list_: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminAddProfanityFilterIntoList.create(
        body=body,
        list_=list_,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminAddProfanityFilters)
def admin_add_profanity_filters(
    body: ModelsAdminAddProfanityFiltersRequest,
    list_: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminAddProfanityFilters.create(
        body=body,
        list_=list_,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminAddProfanityFilters)
async def admin_add_profanity_filters_async(
    body: ModelsAdminAddProfanityFiltersRequest,
    list_: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminAddProfanityFilters.create(
        body=body,
        list_=list_,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminCreateProfanityList)
def admin_create_profanity_list(
    body: ModelsAdminCreateProfanityListRequest,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminCreateProfanityList.create(
        body=body,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminCreateProfanityList)
async def admin_create_profanity_list_async(
    body: ModelsAdminCreateProfanityListRequest,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminCreateProfanityList.create(
        body=body,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminDebugProfanityFilters)
def admin_debug_profanity_filters(
    body: ModelsDebugProfanityFilterRequest,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminDebugProfanityFilters.create(
        body=body,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminDebugProfanityFilters)
async def admin_debug_profanity_filters_async(
    body: ModelsDebugProfanityFilterRequest,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminDebugProfanityFilters.create(
        body=body,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminDeleteProfanityFilter)
def admin_delete_profanity_filter(
    body: ModelsAdminDeleteProfanityFilterRequest,
    list_: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminDeleteProfanityFilter.create(
        body=body,
        list_=list_,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminDeleteProfanityFilter)
async def admin_delete_profanity_filter_async(
    body: ModelsAdminDeleteProfanityFilterRequest,
    list_: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminDeleteProfanityFilter.create(
        body=body,
        list_=list_,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminDeleteProfanityList)
def admin_delete_profanity_list(
    list_: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminDeleteProfanityList.create(
        list_=list_,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminDeleteProfanityList)
async def admin_delete_profanity_list_async(
    list_: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminDeleteProfanityList.create(
        list_=list_,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminGetProfanityListFiltersV1)
def admin_get_profanity_list_filters_v1(
    list_: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminGetProfanityListFiltersV1.create(
        list_=list_,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminGetProfanityListFiltersV1)
async def admin_get_profanity_list_filters_v1_async(
    list_: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminGetProfanityListFiltersV1.create(
        list_=list_,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminGetProfanityLists)
def admin_get_profanity_lists(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminGetProfanityLists.create(
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminGetProfanityLists)
async def admin_get_profanity_lists_async(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminGetProfanityLists.create(
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminGetProfanityRule)
def admin_get_profanity_rule(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminGetProfanityRule.create(
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminGetProfanityRule)
async def admin_get_profanity_rule_async(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminGetProfanityRule.create(
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminImportProfanityFiltersFromFile)
def admin_import_profanity_filters_from_file(
    body: List[int],
    list_: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminImportProfanityFiltersFromFile.create(
        body=body,
        list_=list_,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminImportProfanityFiltersFromFile)
async def admin_import_profanity_filters_from_file_async(
    body: List[int],
    list_: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminImportProfanityFiltersFromFile.create(
        body=body,
        list_=list_,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminSetProfanityRuleForNamespace)
def admin_set_profanity_rule_for_namespace(
    body: ModelsAdminSetProfanityRuleForNamespaceRequest,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminSetProfanityRuleForNamespace.create(
        body=body,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminSetProfanityRuleForNamespace)
async def admin_set_profanity_rule_for_namespace_async(
    body: ModelsAdminSetProfanityRuleForNamespaceRequest,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminSetProfanityRuleForNamespace.create(
        body=body,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminUpdateProfanityList)
def admin_update_profanity_list(
    body: ModelsAdminUpdateProfanityList,
    list_: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminUpdateProfanityList.create(
        body=body,
        list_=list_,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminUpdateProfanityList)
async def admin_update_profanity_list_async(
    body: ModelsAdminUpdateProfanityList,
    list_: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminUpdateProfanityList.create(
        body=body,
        list_=list_,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminVerifyMessageProfanityResponse)
def admin_verify_message_profanity_response(
    body: ModelsAdminVerifyMessageProfanityRequest,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminVerifyMessageProfanityResponse.create(
        body=body,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminVerifyMessageProfanityResponse)
async def admin_verify_message_profanity_response_async(
    body: ModelsAdminVerifyMessageProfanityRequest,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminVerifyMessageProfanityResponse.create(
        body=body,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: accelbyte_cloud_py_codegen

# AccelByte Cloud Iam Service (5.18.0)

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model


class OauthcommonJWKKey(Model):
    """Oauthcommon JWK key (oauthcommon.JWKKey)

    Properties:
        kty: (kty) REQUIRED str

        alg: (alg) OPTIONAL str

        e: (e) OPTIONAL str

        kid: (kid) OPTIONAL str

        n: (n) OPTIONAL str

        use: (use) OPTIONAL str
    """

    # region fields

    kty: str  # REQUIRED
    alg: str  # OPTIONAL
    e: str  # OPTIONAL
    kid: str  # OPTIONAL
    n: str  # OPTIONAL
    use: str  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_kty(self, value: str) -> OauthcommonJWKKey:
        self.kty = value
        return self

    def with_alg(self, value: str) -> OauthcommonJWKKey:
        self.alg = value
        return self

    def with_e(self, value: str) -> OauthcommonJWKKey:
        self.e = value
        return self

    def with_kid(self, value: str) -> OauthcommonJWKKey:
        self.kid = value
        return self

    def with_n(self, value: str) -> OauthcommonJWKKey:
        self.n = value
        return self

    def with_use(self, value: str) -> OauthcommonJWKKey:
        self.use = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "kty"):
            result["kty"] = str(self.kty)
        elif include_empty:
            result["kty"] = ""
        if hasattr(self, "alg"):
            result["alg"] = str(self.alg)
        elif include_empty:
            result["alg"] = ""
        if hasattr(self, "e"):
            result["e"] = str(self.e)
        elif include_empty:
            result["e"] = ""
        if hasattr(self, "kid"):
            result["kid"] = str(self.kid)
        elif include_empty:
            result["kid"] = ""
        if hasattr(self, "n"):
            result["n"] = str(self.n)
        elif include_empty:
            result["n"] = ""
        if hasattr(self, "use"):
            result["use"] = str(self.use)
        elif include_empty:
            result["use"] = ""
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        kty: str,
        alg: Optional[str] = None,
        e: Optional[str] = None,
        kid: Optional[str] = None,
        n: Optional[str] = None,
        use: Optional[str] = None,
    ) -> OauthcommonJWKKey:
        instance = cls()
        instance.kty = kty
        if alg is not None:
            instance.alg = alg
        if e is not None:
            instance.e = e
        if kid is not None:
            instance.kid = kid
        if n is not None:
            instance.n = n
        if use is not None:
            instance.use = use
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> OauthcommonJWKKey:
        instance = cls()
        if not dict_:
            return instance
        if "kty" in dict_ and dict_["kty"] is not None:
            instance.kty = str(dict_["kty"])
        elif include_empty:
            instance.kty = ""
        if "alg" in dict_ and dict_["alg"] is not None:
            instance.alg = str(dict_["alg"])
        elif include_empty:
            instance.alg = ""
        if "e" in dict_ and dict_["e"] is not None:
            instance.e = str(dict_["e"])
        elif include_empty:
            instance.e = ""
        if "kid" in dict_ and dict_["kid"] is not None:
            instance.kid = str(dict_["kid"])
        elif include_empty:
            instance.kid = ""
        if "n" in dict_ and dict_["n"] is not None:
            instance.n = str(dict_["n"])
        elif include_empty:
            instance.n = ""
        if "use" in dict_ and dict_["use"] is not None:
            instance.use = str(dict_["use"])
        elif include_empty:
            instance.use = ""
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, OauthcommonJWKKey]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[OauthcommonJWKKey]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        OauthcommonJWKKey, List[OauthcommonJWKKey], Dict[Any, OauthcommonJWKKey]
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "kty": "kty",
            "alg": "alg",
            "e": "e",
            "kid": "kid",
            "n": "n",
            "use": "use",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "kty": True,
            "alg": False,
            "e": False,
            "kid": False,
            "n": False,
            "use": False,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: accelbyte_cloud_py_codegen

"""Auto-generated package that contains models used by the AccelByte Cloud Social Service."""

__version__ = "1.29.6"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .get_profile import GetProfile
from .get_user_profiles import GetUserProfiles
from .public_create_profile import PublicCreateProfile
from .public_delete_profile import PublicDeleteProfile
from .public_get_profile import PublicGetProfile
from .public_get_profile_attribute import PublicGetProfileAttribute
from .public_get_user_game_profiles import PublicGetUserGameProfiles
from .public_get_user_profiles import PublicGetUserProfiles
from .public_update_attribute import PublicUpdateAttribute
from .public_update_profile import PublicUpdateProfile



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: accelbyte_cloud_py_codegen

"""Auto-generated package that contains models used by the AccelByte Cloud Group Service."""

__version__ = "2.11.7"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .models_assign_role_to_member_request_v1 import ModelsAssignRoleToMemberRequestV1
from .models_create_group_configuration_request_v1 import (
    ModelsCreateGroupConfigurationRequestV1,
)
from .models_create_group_configuration_response_v1 import (
    ModelsCreateGroupConfigurationResponseV1,
)
from .models_create_member_role_request_v1 import ModelsCreateMemberRoleRequestV1
from .models_create_member_role_response_v1 import ModelsCreateMemberRoleResponseV1
from .models_get_group_configuration_response_v1 import (
    ModelsGetGroupConfigurationResponseV1,
)
from .models_get_group_member_list_response_v1 import ModelsGetGroupMemberListResponseV1
from .models_get_groups_list_response_v1 import ModelsGetGroupsListResponseV1
from .models_get_member_requests_list_response_v1 import (
    ModelsGetMemberRequestsListResponseV1,
)
from .models_get_member_role_response_v1 import ModelsGetMemberRoleResponseV1
from .models_get_member_roles_list_response_v1 import ModelsGetMemberRolesListResponseV1
from .models_get_user_group_information_response_v1 import (
    ModelsGetUserGroupInformationResponseV1,
)
from .models_group_member import ModelsGroupMember
from .models_group_response_v1 import ModelsGroupResponseV1
from .models_group_rule import ModelsGroupRule
from .models_group_rule_group_custom_rule import ModelsGroupRuleGroupCustomRule
from .models_join_group_response_v1 import ModelsJoinGroupResponseV1
from .models_kick_group_member_response_v1 import ModelsKickGroupMemberResponseV1
from .models_leave_group_response_v1 import ModelsLeaveGroupResponseV1
from .models_list_configuration_response_v1 import ModelsListConfigurationResponseV1
from .models_member_request_group_response_v1 import ModelsMemberRequestGroupResponseV1
from .models_member_request_response_v1 import ModelsMemberRequestResponseV1
from .models_pagination import ModelsPagination
from .models_public_create_new_group_request_v1 import (
    ModelsPublicCreateNewGroupRequestV1,
)
from .models_remove_role_from_member_request_v1 import (
    ModelsRemoveRoleFromMemberRequestV1,
)
from .models_role_permission import ModelsRolePermission
from .models_rule import ModelsRule
from .models_rule_information import ModelsRuleInformation
from .models_rule_information import (
    RuleCriteriaEnum as ModelsRuleInformationRuleCriteriaEnum,
)
from .models_update_group_configuration_global_rules_request_v1 import (
    ModelsUpdateGroupConfigurationGlobalRulesRequestV1,
)
from .models_update_group_configuration_request_v1 import (
    ModelsUpdateGroupConfigurationRequestV1,
)
from .models_update_group_configuration_response_v1 import (
    ModelsUpdateGroupConfigurationResponseV1,
)
from .models_update_group_custom_attributes_request_v1 import (
    ModelsUpdateGroupCustomAttributesRequestV1,
)
from .models_update_group_custom_rule_request_v1 import (
    ModelsUpdateGroupCustomRuleRequestV1,
)
from .models_update_group_predefined_rule_request_v1 import (
    ModelsUpdateGroupPredefinedRuleRequestV1,
)
from .models_update_group_request_v1 import ModelsUpdateGroupRequestV1
from .models_update_group_request_v1_custom_attributes import (
    ModelsUpdateGroupRequestV1CustomAttributes,
)
from .models_update_member_role_permissions_request_v1 import (
    ModelsUpdateMemberRolePermissionsRequestV1,
)
from .models_update_member_role_request_v1 import ModelsUpdateMemberRoleRequestV1
from .models_update_member_role_response_v1 import ModelsUpdateMemberRoleResponseV1
from .models_user_invitation_response_v1 import ModelsUserInvitationResponseV1
from .response_error_response import ResponseErrorResponse



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: accelbyte_cloud_py_codegen

# AccelByte Cloud Basic Service (2.1.3)

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model


class ADTOObjectForEqu8UserStatus(Model):
    """A DTO object for equ8 user status (A DTO object for equ8 user status)

    Properties:
        action_comment: (actionComment) OPTIONAL str

        action_id: (actionId) OPTIONAL int

        expires: (expires) OPTIONAL str

        user_id: (userId) OPTIONAL str

        when: (when) OPTIONAL str
    """

    # region fields

    action_comment: str  # OPTIONAL
    action_id: int  # OPTIONAL
    expires: str  # OPTIONAL
    user_id: str  # OPTIONAL
    when: str  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_action_comment(self, value: str) -> ADTOObjectForEqu8UserStatus:
        self.action_comment = value
        return self

    def with_action_id(self, value: int) -> ADTOObjectForEqu8UserStatus:
        self.action_id = value
        return self

    def with_expires(self, value: str) -> ADTOObjectForEqu8UserStatus:
        self.expires = value
        return self

    def with_user_id(self, value: str) -> ADTOObjectForEqu8UserStatus:
        self.user_id = value
        return self

    def with_when(self, value: str) -> ADTOObjectForEqu8UserStatus:
        self.when = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "action_comment"):
            result["actionComment"] = str(self.action_comment)
        elif include_empty:
            result["actionComment"] = ""
        if hasattr(self, "action_id"):
            result["actionId"] = int(self.action_id)
        elif include_empty:
            result["actionId"] = 0
        if hasattr(self, "expires"):
            result["expires"] = str(self.expires)
        elif include_empty:
            result["expires"] = ""
        if hasattr(self, "user_id"):
            result["userId"] = str(self.user_id)
        elif include_empty:
            result["userId"] = ""
        if hasattr(self, "when"):
            result["when"] = str(self.when)
        elif include_empty:
            result["when"] = ""
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        action_comment: Optional[str] = None,
        action_id: Optional[int] = None,
        expires: Optional[str] = None,
        user_id: Optional[str] = None,
        when: Optional[str] = None,
    ) -> ADTOObjectForEqu8UserStatus:
        instance = cls()
        if action_comment is not None:
            instance.action_comment = action_comment
        if action_id is not None:
            instance.action_id = action_id
        if expires is not None:
            instance.expires = expires
        if user_id is not None:
            instance.user_id = user_id
        if when is not None:
            instance.when = when
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ADTOObjectForEqu8UserStatus:
        instance = cls()
        if not dict_:
            return instance
        if "actionComment" in dict_ and dict_["actionComment"] is not None:
            instance.action_comment = str(dict_["actionComment"])
        elif include_empty:
            instance.action_comment = ""
        if "actionId" in dict_ and dict_["actionId"] is not None:
            instance.action_id = int(dict_["actionId"])
        elif include_empty:
            instance.action_id = 0
        if "expires" in dict_ and dict_["expires"] is not None:
            instance.expires = str(dict_["expires"])
        elif include_empty:
            instance.expires = ""
        if "userId" in dict_ and dict_["userId"] is not None:
            instance.user_id = str(dict_["userId"])
        elif include_empty:
            instance.user_id = ""
        if "when" in dict_ and dict_["when"] is not None:
            instance.when = str(dict_["when"])
        elif include_empty:
            instance.when = ""
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ADTOObjectForEqu8UserStatus]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ADTOObjectForEqu8UserStatus]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ADTOObjectForEqu8UserStatus,
        List[ADTOObjectForEqu8UserStatus],
        Dict[Any, ADTOObjectForEqu8UserStatus],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "actionComment": "action_comment",
            "actionId": "action_id",
            "expires": "expires",
            "userId": "user_id",
            "when": "when",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "actionComment": False,
            "actionId": False,
            "expires": False,
            "userId": False,
            "when": False,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: accelbyte_cloud_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

# Analytics Game Telemetry (1.10.0)

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from .....core import Operation
from .....core import HeaderStr
from .....core import HttpResponse

from ...models import HTTPValidationError


class GetEventsGameTelemetryV1AdminNamespacesNamespaceEventsGet(Operation):
    """Get Events (get_events_game_telemetry_v1_admin_namespaces__namespace__events_get)

    Properties:
        url: /game-telemetry/v1/admin/namespaces/{namespace}/events

        method: GET

        tags: []

        consumes: []

        produces: ["application/json"]

        securities: [COOKIE_AUTH] or [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        end_time: (endTime) OPTIONAL str in query

        event_id: (eventId) OPTIONAL str in query

        event_name: (eventName) OPTIONAL str in query

        event_payload: (eventPayload) OPTIONAL str in query

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        start_time: (startTime) OPTIONAL str in query

    Responses:
        200: OK - (Successful Response)

        422: Unprocessable Entity - HTTPValidationError (Validation Error)
    """

    # region fields

    _url: str = "/game-telemetry/v1/admin/namespaces/{namespace}/events"
    _method: str = "GET"
    _consumes: List[str] = []
    _produces: List[str] = ["application/json"]
    _securities: List[List[str]] = [["COOKIE_AUTH"], ["BEARER_AUTH"]]
    _location_query: str = None

    namespace: str  # REQUIRED in [path]
    end_time: str  # OPTIONAL in [query]
    event_id: str  # OPTIONAL in [query]
    event_name: str  # OPTIONAL in [query]
    event_payload: str  # OPTIONAL in [query]
    limit: int  # OPTIONAL in [query]
    offset: int  # OPTIONAL in [query]
    start_time: str  # OPTIONAL in [query]

    # endregion fields

    # region properties

    @property
    def url(self) -> str:
        return self._url

    @property
    def method(self) -> str:
        return self._method

    @property
    def consumes(self) -> List[str]:
        return self._consumes

    @property
    def produces(self) -> List[str]:
        return self._produces

    @property
    def securities(self) -> List[List[str]]:
        return self._securities

    @property
    def location_query(self) -> str:
        return self._location_query

    # endregion properties

    # region get methods

    # endregion get methods

    # region get_x_params methods

    def get_all_params(self) -> dict:
        return {
            "path": self.get_path_params(),
            "query": self.get_query_params(),
        }

    def get_path_params(self) -> dict:
        result = {}
        if hasattr(self, "namespace"):
            result["namespace"] = self.namespace
        return result

    def get_query_params(self) -> dict:
        result = {}
        if hasattr(self, "end_time"):
            result["endTime"] = self.end_time
        if hasattr(self, "event_id"):
            result["eventId"] = self.event_id
        if hasattr(self, "event_name"):
            result["eventName"] = self.event_name
        if hasattr(self, "event_payload"):
            result["eventPayload"] = self.event_payload
        if hasattr(self, "limit"):
            result["limit"] = self.limit
        if hasattr(self, "offset"):
            result["offset"] = self.offset
        if hasattr(self, "start_time"):
            result["startTime"] = self.start_time
        return result

    # endregion get_x_params methods

    # region is/has methods

    # endregion is/has methods

    # region with_x methods

    def with_namespace(
        self, value: str
    ) -> GetEventsGameTelemetryV1AdminNamespacesNamespaceEventsGet:
        self.namespace = value
        return self

    def with_end_time(
        self, value: str
    ) -> GetEventsGameTelemetryV1AdminNamespacesNamespaceEventsGet:
        self.end_time = value
        return self

    def with_event_id(
        self, value: str
    ) -> GetEventsGameTelemetryV1AdminNamespacesNamespaceEventsGet:
        self.event_id = value
        return self

    def with_event_name(
        self, value: str
    ) -> GetEventsGameTelemetryV1AdminNamespacesNamespaceEventsGet:
        self.event_name = value
        return self

    def with_event_payload(
        self, value: str
    ) -> GetEventsGameTelemetryV1AdminNamespacesNamespaceEventsGet:
        self.event_payload = value
        return self

    def with_limit(
        self, value: int
    ) -> GetEventsGameTelemetryV1AdminNamespacesNamespaceEventsGet:
        self.limit = value
        return self

    def with_offset(
        self, value: int
    ) -> GetEventsGameTelemetryV1AdminNamespacesNamespaceEventsGet:
        self.offset = value
        return self

    def with_start_time(
        self, value: str
    ) -> GetEventsGameTelemetryV1AdminNamespacesNamespaceEventsGet:
        self.start_time = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "namespace") and self.namespace:
            result["namespace"] = str(self.namespace)
        elif include_empty:
            result["namespace"] = ""
        if hasattr(self, "end_time") and self.end_time:
            result["endTime"] = str(self.end_time)
        elif include_empty:
            result["endTime"] = ""
        if hasattr(self, "event_id") and self.event_id:
            result["eventId"] = str(self.event_id)
        elif include_empty:
            result["eventId"] = ""
        if hasattr(self, "event_name") and self.event_name:
            result["eventName"] = str(self.event_name)
        elif include_empty:
            result["eventName"] = ""
        if hasattr(self, "event_payload") and self.event_payload:
            result["eventPayload"] = str(self.event_payload)
        elif include_empty:
            result["eventPayload"] = ""
        if hasattr(self, "limit") and self.limit:
            result["limit"] = int(self.limit)
        elif include_empty:
            result["limit"] = 0
        if hasattr(self, "offset") and self.offset:
            result["offset"] = int(self.offset)
        elif include_empty:
            result["offset"] = 0
        if hasattr(self, "start_time") and self.start_time:
            result["startTime"] = str(self.start_time)
        elif include_empty:
            result["startTime"] = ""
        return result

    # endregion to methods

    # region response methods

    # noinspection PyMethodMayBeStatic
    def parse_response(
        self, code: int, content_type: str, content: Any
    ) -> Tuple[
        Union[None, HttpResponse], Union[None, HTTPValidationError, HttpResponse]
    ]:
        """Parse the given response.

        200: OK - (Successful Response)

        422: Unprocessable Entity - HTTPValidationError (Validation Error)

        ---: HttpResponse (Undocumented Response)

        ---: HttpResponse (Unexpected Content-Type Error)

        ---: HttpResponse (Unhandled Error)
        """
        pre_processed_response, error = self.pre_process_response(
            code=code, content_type=content_type, content=content
        )
        if error is not None:
            return None, None if error.is_no_content() else error
        code, content_type, content = pre_processed_response

        if code == 200:
            return HttpResponse.create(code, "OK"), None
        if code == 422:
            return None, HTTPValidationError.create_from_dict(content)

        return self.handle_undocumented_response(
            code=code, content_type=content_type, content=content
        )

    # endregion response methods

    # region static methods

    @classmethod
    def create(
        cls,
        namespace: str,
        end_time: Optional[str] = None,
        event_id: Optional[str] = None,
        event_name: Optional[str] = None,
        event_payload: Optional[str] = None,
        limit: Optional[int] = None,
        offset: Optional[int] = None,
        start_time: Optional[str] = None,
    ) -> GetEventsGameTelemetryV1AdminNamespacesNamespaceEventsGet:
        instance = cls()
        instance.namespace = namespace
        if end_time is not None:
            instance.end_time = end_time
        if event_id is not None:
            instance.event_id = event_id
        if event_name is not None:
            instance.event_name = event_name
        if event_payload is not None:
            instance.event_payload = event_payload
        if limit is not None:
            instance.limit = limit
        if offset is not None:
            instance.offset = offset
        if start_time is not None:
            instance.start_time = start_time
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> GetEventsGameTelemetryV1AdminNamespacesNamespaceEventsGet:
        instance = cls()
        if "namespace" in dict_ and dict_["namespace"] is not None:
            instance.namespace = str(dict_["namespace"])
        elif include_empty:
            instance.namespace = ""
        if "endTime" in dict_ and dict_["endTime"] is not None:
            instance.end_time = str(dict_["endTime"])
        elif include_empty:
            instance.end_time = ""
        if "eventId" in dict_ and dict_["eventId"] is not None:
            instance.event_id = str(dict_["eventId"])
        elif include_empty:
            instance.event_id = ""
        if "eventName" in dict_ and dict_["eventName"] is not None:
            instance.event_name = str(dict_["eventName"])
        elif include_empty:
            instance.event_name = ""
        if "eventPayload" in dict_ and dict_["eventPayload"] is not None:
            instance.event_payload = str(dict_["eventPayload"])
        elif include_empty:
            instance.event_payload = ""
        if "limit" in dict_ and dict_["limit"] is not None:
            instance.limit = int(dict_["limit"])
        elif include_empty:
            instance.limit = 0
        if "offset" in dict_ and dict_["offset"] is not None:
            instance.offset = int(dict_["offset"])
        elif include_empty:
            instance.offset = 0
        if "startTime" in dict_ and dict_["startTime"] is not None:
            instance.start_time = str(dict_["startTime"])
        elif include_empty:
            instance.start_time = ""
        return instance

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "namespace": "namespace",
            "endTime": "end_time",
            "eventId": "event_id",
            "eventName": "event_name",
            "eventPayload": "event_payload",
            "limit": "limit",
            "offset": "offset",
            "startTime": "start_time",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "namespace": True,
            "endTime": False,
            "eventId": False,
            "eventName": False,
            "eventPayload": False,
            "limit": False,
            "offset": False,
            "startTime": False,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: accelbyte_cloud_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

# AccelByte Cloud Platform Service (4.15.0)

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from .....core import Operation
from .....core import HeaderStr
from .....core import HttpResponse
from .....core import StrEnum

from ...models import SubscriptionPagingSlicedResult


class ChargeStatusEnum(StrEnum):
    CHARGED = "CHARGED"
    CHARGE_FAILED = "CHARGE_FAILED"
    NEVER = "NEVER"
    RECURRING_CHARGING = "RECURRING_CHARGING"
    SETUP = "SETUP"


class StatusEnum(StrEnum):
    ACTIVE = "ACTIVE"
    CANCELLED = "CANCELLED"
    EXPIRED = "EXPIRED"
    INIT = "INIT"


class SubscribedByEnum(StrEnum):
    PLATFORM = "PLATFORM"
    USER = "USER"


class QueryUserSubscriptions(Operation):
    """Query user subscriptions (queryUserSubscriptions)

    Query user subscriptions.
    Other detail info:

      * Required permission : resource="ADMIN:NAMESPACE:{namespace}:USER:{userId}:SUBSCRIPTION", action=2 (READ)
      *  Returns : paginated subscription

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:USER:{userId}:SUBSCRIPTION [READ]

    Properties:
        url: /platform/admin/namespaces/{namespace}/users/{userId}/subscriptions

        method: GET

        tags: ["Subscription"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH] or [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

        charge_status: (chargeStatus) OPTIONAL Union[str, ChargeStatusEnum] in query

        item_id: (itemId) OPTIONAL str in query

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        sku: (sku) OPTIONAL str in query

        status: (status) OPTIONAL Union[str, StatusEnum] in query

        subscribed_by: (subscribedBy) OPTIONAL Union[str, SubscribedByEnum] in query

    Responses:
        200: OK - SubscriptionPagingSlicedResult (successful operation)
    """

    # region fields

    _url: str = "/platform/admin/namespaces/{namespace}/users/{userId}/subscriptions"
    _method: str = "GET"
    _consumes: List[str] = ["application/json"]
    _produces: List[str] = ["application/json"]
    _securities: List[List[str]] = [["BEARER_AUTH"], ["BEARER_AUTH"]]
    _location_query: str = None

    namespace: str  # REQUIRED in [path]
    user_id: str  # REQUIRED in [path]
    charge_status: Union[str, ChargeStatusEnum]  # OPTIONAL in [query]
    item_id: str  # OPTIONAL in [query]
    limit: int  # OPTIONAL in [query]
    offset: int  # OPTIONAL in [query]
    sku: str  # OPTIONAL in [query]
    status: Union[str, StatusEnum]  # OPTIONAL in [query]
    subscribed_by: Union[str, SubscribedByEnum]  # OPTIONAL in [query]

    # endregion fields

    # region properties

    @property
    def url(self) -> str:
        return self._url

    @property
    def method(self) -> str:
        return self._method

    @property
    def consumes(self) -> List[str]:
        return self._consumes

    @property
    def produces(self) -> List[str]:
        return self._produces

    @property
    def securities(self) -> List[List[str]]:
        return self._securities

    @property
    def location_query(self) -> str:
        return self._location_query

    # endregion properties

    # region get methods

    # endregion get methods

    # region get_x_params methods

    def get_all_params(self) -> dict:
        return {
            "path": self.get_path_params(),
            "query": self.get_query_params(),
        }

    def get_path_params(self) -> dict:
        result = {}
        if hasattr(self, "namespace"):
            result["namespace"] = self.namespace
        if hasattr(self, "user_id"):
            result["userId"] = self.user_id
        return result

    def get_query_params(self) -> dict:
        result = {}
        if hasattr(self, "charge_status"):
            result["chargeStatus"] = self.charge_status
        if hasattr(self, "item_id"):
            result["itemId"] = self.item_id
        if hasattr(self, "limit"):
            result["limit"] = self.limit
        if hasattr(self, "offset"):
            result["offset"] = self.offset
        if hasattr(self, "sku"):
            result["sku"] = self.sku
        if hasattr(self, "status"):
            result["status"] = self.status
        if hasattr(self, "subscribed_by"):
            result["subscribedBy"] = self.subscribed_by
        return result

    # endregion get_x_params methods

    # region is/has methods

    # endregion is/has methods

    # region with_x methods

    def with_namespace(self, value: str) -> QueryUserSubscriptions:
        self.namespace = value
        return self

    def with_user_id(self, value: str) -> QueryUserSubscriptions:
        self.user_id = value
        return self

    def with_charge_status(
        self, value: Union[str, ChargeStatusEnum]
    ) -> QueryUserSubscriptions:
        self.charge_status = value
        return self

    def with_item_id(self, value: str) -> QueryUserSubscriptions:
        self.item_id = value
        return self

    def with_limit(self, value: int) -> QueryUserSubscriptions:
        self.limit = value
        return self

    def with_offset(self, value: int) -> QueryUserSubscriptions:
        self.offset = value
        return self

    def with_sku(self, value: str) -> QueryUserSubscriptions:
        self.sku = value
        return self

    def with_status(self, value: Union[str, StatusEnum]) -> QueryUserSubscriptions:
        self.status = value
        return self

    def with_subscribed_by(
        self, value: Union[str, SubscribedByEnum]
    ) -> QueryUserSubscriptions:
        self.subscribed_by = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "namespace") and self.namespace:
            result["namespace"] = str(self.namespace)
        elif include_empty:
            result["namespace"] = ""
        if hasattr(self, "user_id") and self.user_id:
            result["userId"] = str(self.user_id)
        elif include_empty:
            result["userId"] = ""
        if hasattr(self, "charge_status") and self.charge_status:
            result["chargeStatus"] = str(self.charge_status)
        elif include_empty:
            result["chargeStatus"] = Union[str, ChargeStatusEnum]()
        if hasattr(self, "item_id") and self.item_id:
            result["itemId"] = str(self.item_id)
        elif include_empty:
            result["itemId"] = ""
        if hasattr(self, "limit") and self.limit:
            result["limit"] = int(self.limit)
        elif include_empty:
            result["limit"] = 0
        if hasattr(self, "offset") and self.offset:
            result["offset"] = int(self.offset)
        elif include_empty:
            result["offset"] = 0
        if hasattr(self, "sku") and self.sku:
            result["sku"] = str(self.sku)
        elif include_empty:
            result["sku"] = ""
        if hasattr(self, "status") and self.status:
            result["status"] = str(self.status)
        elif include_empty:
            result["status"] = Union[str, StatusEnum]()
        if hasattr(self, "subscribed_by") and self.subscribed_by:
            result["subscribedBy"] = str(self.subscribed_by)
        elif include_empty:
            result["subscribedBy"] = Union[str, SubscribedByEnum]()
        return result

    # endregion to methods

    # region response methods

    # noinspection PyMethodMayBeStatic
    def parse_response(
        self, code: int, content_type: str, content: Any
    ) -> Tuple[Union[None, SubscriptionPagingSlicedResult], Union[None, HttpResponse]]:
        """Parse the given response.

        200: OK - SubscriptionPagingSlicedResult (successful operation)

        ---: HttpResponse (Undocumented Response)

        ---: HttpResponse (Unexpected Content-Type Error)

        ---: HttpResponse (Unhandled Error)
        """
        pre_processed_response, error = self.pre_process_response(
            code=code, content_type=content_type, content=content
        )
        if error is not None:
            return None, None if error.is_no_content() else error
        code, content_type, content = pre_processed_response

        if code == 200:
            return SubscriptionPagingSlicedResult.create_from_dict(content), None

        return self.handle_undocumented_response(
            code=code, content_type=content_type, content=content
        )

    # endregion response methods

    # region static methods

    @classmethod
    def create(
        cls,
        namespace: str,
        user_id: str,
        charge_status: Optional[Union[str, ChargeStatusEnum]] = None,
        item_id: Optional[str] = None,
        limit: Optional[int] = None,
        offset: Optional[int] = None,
        sku: Optional[str] = None,
        status: Optional[Union[str, StatusEnum]] = None,
        subscribed_by: Optional[Union[str, SubscribedByEnum]] = None,
    ) -> QueryUserSubscriptions:
        instance = cls()
        instance.namespace = namespace
        instance.user_id = user_id
        if charge_status is not None:
            instance.charge_status = charge_status
        if item_id is not None:
            instance.item_id = item_id
        if limit is not None:
            instance.limit = limit
        if offset is not None:
            instance.offset = offset
        if sku is not None:
            instance.sku = sku
        if status is not None:
            instance.status = status
        if subscribed_by is not None:
            instance.subscribed_by = subscribed_by
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> QueryUserSubscriptions:
        instance = cls()
        if "namespace" in dict_ and dict_["namespace"] is not None:
            instance.namespace = str(dict_["namespace"])
        elif include_empty:
            instance.namespace = ""
        if "userId" in dict_ and dict_["userId"] is not None:
            instance.user_id = str(dict_["userId"])
        elif include_empty:
            instance.user_id = ""
        if "chargeStatus" in dict_ and dict_["chargeStatus"] is not None:
            instance.charge_status = str(dict_["chargeStatus"])
        elif include_empty:
            instance.charge_status = Union[str, ChargeStatusEnum]()
        if "itemId" in dict_ and dict_["itemId"] is not None:
            instance.item_id = str(dict_["itemId"])
        elif include_empty:
            instance.item_id = ""
        if "limit" in dict_ and dict_["limit"] is not None:
            instance.limit = int(dict_["limit"])
        elif include_empty:
            instance.limit = 0
        if "offset" in dict_ and dict_["offset"] is not None:
            instance.offset = int(dict_["offset"])
        elif include_empty:
            instance.offset = 0
        if "sku" in dict_ and dict_["sku"] is not None:
            instance.sku = str(dict_["sku"])
        elif include_empty:
            instance.sku = ""
        if "status" in dict_ and dict_["status"] is not None:
            instance.status = str(dict_["status"])
        elif include_empty:
            instance.status = Union[str, StatusEnum]()
        if "subscribedBy" in dict_ and dict_["subscribedBy"] is not None:
            instance.subscribed_by = str(dict_["subscribedBy"])
        elif include_empty:
            instance.subscribed_by = Union[str, SubscribedByEnum]()
        return instance

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "namespace": "namespace",
            "userId": "user_id",
            "chargeStatus": "charge_status",
            "itemId": "item_id",
            "limit": "limit",
            "offset": "offset",
            "sku": "sku",
            "status": "status",
            "subscribedBy": "subscribed_by",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "namespace": True,
            "userId": True,
            "chargeStatus": False,
            "itemId": False,
            "limit": False,
            "offset": False,
            "sku": False,
            "status": False,
            "subscribedBy": False,
        }

    @staticmethod
    def get_enum_map() -> Dict[str, List[Any]]:
        return {
            "chargeStatus": [
                "CHARGED",
                "CHARGE_FAILED",
                "NEVER",
                "RECURRING_CHARGING",
                "SETUP",
            ],  # in query
            "status": ["ACTIVE", "CANCELLED", "EXPIRED", "INIT"],  # in query
            "subscribedBy": ["PLATFORM", "USER"],  # in query
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: accelbyte_cloud_py_codegen

"""Auto-generated package that contains models used by the AccelByte Cloud Dsm Controller Service."""

__version__ = "3.8.0"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .create_deployment import CreateDeployment
from .create_deployment_override import CreateDeploymentOverride
from .create_override_region__89178f import CreateOverrideRegionOverride
from .create_root_region_override import CreateRootRegionOverride
from .delete_deployment import DeleteDeployment
from .delete_deployment_override import DeleteDeploymentOverride
from .delete_override_region__2e7e2d import DeleteOverrideRegionOverride
from .delete_root_region_override import DeleteRootRegionOverride
from .get_all_deployment import GetAllDeployment
from .get_deployment import GetDeployment
from .update_deployment import UpdateDeployment
from .update_deployment_override import UpdateDeploymentOverride
from .update_override_region__fb90bf import UpdateOverrideRegionOverride
from .update_root_region_override import UpdateRootRegionOverride



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: accelbyte_cloud_py_codegen

"""Auto-generated package that contains models used by the AccelByte Cloud Legal Service."""

__version__ = "1.23.0"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from ._admin_user_agreement import indirect_bulk_accept_versioned_policy
from ._admin_user_agreement import indirect_bulk_accept_versioned_policy_async

from ._admin_user_eligibilities import admin_retrieve_eligibilities
from ._admin_user_eligibilities import admin_retrieve_eligibilities_async

from ._agreement import accept_versioned_policy
from ._agreement import accept_versioned_policy_async
from ._agreement import bulk_accept_versioned_policy
from ._agreement import bulk_accept_versioned_policy_async
from ._agreement import change_preference_consent
from ._agreement import change_preference_consent_async
from ._agreement import change_preference_consent_1
from ._agreement import change_preference_consent_1_async
from ._agreement import indirect_bulk_accept_versioned_policy_1
from ._agreement import indirect_bulk_accept_versioned_policy_1_async
from ._agreement import indirect_bulk_accept_versioned_policy_v2
from ._agreement import indirect_bulk_accept_versioned_policy_v2_async
from ._agreement import retrieve_accepted_agreements
from ._agreement import retrieve_accepted_agreements_async
from ._agreement import retrieve_agreements_public
from ._agreement import retrieve_agreements_public_async
from ._agreement import retrieve_all_users_by_policy_version
from ._agreement import retrieve_all_users_by_policy_version_async

from ._anonymization import anonymize_user_agreement
from ._anonymization import anonymize_user_agreement_async

from ._base_legal_policies import create_policy
from ._base_legal_policies import create_policy_async
from ._base_legal_policies import partial_update_policy
from ._base_legal_policies import partial_update_policy_async
from ._base_legal_policies import retrieve_all_legal_policies
from ._base_legal_policies import retrieve_all_legal_policies_async
from ._base_legal_policies import retrieve_all_policy_types
from ._base_legal_policies import retrieve_all_policy_types_async
from ._base_legal_policies import retrieve_policy_country
from ._base_legal_policies import retrieve_policy_country_async
from ._base_legal_policies import retrieve_single_policy
from ._base_legal_policies import retrieve_single_policy_async

from ._eligibilities import retrieve_eligibilities_public
from ._eligibilities import retrieve_eligibilities_public_async
from ._eligibilities import retrieve_eligibilities_public_indirect
from ._eligibilities import retrieve_eligibilities_public_indirect_async

from ._localized_policy_versions import create_localized_policy_version
from ._localized_policy_versions import create_localized_policy_version_async
from ._localized_policy_versions import request_presigned_url
from ._localized_policy_versions import request_presigned_url_async
from ._localized_policy_versions import retrieve_localized_policy_versions
from ._localized_policy_versions import retrieve_localized_policy_versions_async
from ._localized_policy_versions import retrieve_single_localized_policy_version
from ._localized_policy_versions import retrieve_single_localized_policy_version_async
from ._localized_policy_versions import retrieve_single_localized_policy_version_1
from ._localized_policy_versions import retrieve_single_localized_policy_version_1_async
from ._localized_policy_versions import set_default_policy
from ._localized_policy_versions import set_default_policy_async
from ._localized_policy_versions import update_localized_policy_version
from ._localized_policy_versions import update_localized_policy_version_async

from ._policies import retrieve_latest_policies
from ._policies import retrieve_latest_policies_async
from ._policies import retrieve_latest_policies_by_namespace_and_country_public
from ._policies import retrieve_latest_policies_by_namespace_and_country_public_async
from ._policies import retrieve_latest_policies_public
from ._policies import retrieve_latest_policies_public_async
from ._policies import retrieve_policies
from ._policies import retrieve_policies_async
from ._policies import set_default_policy_1
from ._policies import set_default_policy_1_async
from ._policies import update_policy
from ._policies import update_policy_async

from ._policy_versions import create_policy_version
from ._policy_versions import create_policy_version_async
from ._policy_versions import publish_policy_version
from ._policy_versions import publish_policy_version_async
from ._policy_versions import retrieve_single_policy_version
from ._policy_versions import retrieve_single_policy_version_async
from ._policy_versions import update_policy_version
from ._policy_versions import update_policy_version_async

from ._user_info import get_user_info_status
from ._user_info import get_user_info_status_async
from ._user_info import invalidate_user_info_cache
from ._user_info import invalidate_user_info_cache_async
from ._user_info import sync_user_info
from ._user_info import sync_user_info_async

from ._utility import check_readiness
from ._utility import check_readiness_async



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: accelbyte_cloud_py_codegen

# AccelByte Cloud Platform Service (4.15.0)

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model
from ....core import StrEnum


class ActionEnum(StrEnum):
    CREATE = "CREATE"
    DELETE = "DELETE"
    UPDATE = "UPDATE"


class StatusEnum(StrEnum):
    PUBLISHED = "PUBLISHED"
    UNPUBLISHED = "UNPUBLISHED"


class ItemTypeEnum(StrEnum):
    APP = "APP"
    BUNDLE = "BUNDLE"
    CODE = "CODE"
    COINS = "COINS"
    EXTENSION = "EXTENSION"
    INGAMEITEM = "INGAMEITEM"
    MEDIA = "MEDIA"
    OPTIONBOX = "OPTIONBOX"
    SEASON = "SEASON"
    SUBSCRIPTION = "SUBSCRIPTION"


class TypeEnum(StrEnum):
    CATEGORY = "CATEGORY"
    ITEM = "ITEM"
    STORE = "STORE"


class CatalogChangeInfo(Model):
    """Catalog change info (CatalogChangeInfo)

    Properties:
        action: (action) REQUIRED Union[str, ActionEnum]

        change_id: (changeId) REQUIRED str

        created_at: (createdAt) REQUIRED str

        namespace: (namespace) REQUIRED str

        selected: (selected) REQUIRED bool

        status: (status) REQUIRED Union[str, StatusEnum]

        store_id: (storeId) REQUIRED str

        updated_at: (updatedAt) REQUIRED str

        category_path: (categoryPath) OPTIONAL str

        description: (description) OPTIONAL str

        item_id: (itemId) OPTIONAL str

        item_type: (itemType) OPTIONAL Union[str, ItemTypeEnum]

        published_at: (publishedAt) OPTIONAL str

        sku: (sku) OPTIONAL str

        title: (title) OPTIONAL str

        type_: (type) OPTIONAL Union[str, TypeEnum]
    """

    # region fields

    action: Union[str, ActionEnum]  # REQUIRED
    change_id: str  # REQUIRED
    created_at: str  # REQUIRED
    namespace: str  # REQUIRED
    selected: bool  # REQUIRED
    status: Union[str, StatusEnum]  # REQUIRED
    store_id: str  # REQUIRED
    updated_at: str  # REQUIRED
    category_path: str  # OPTIONAL
    description: str  # OPTIONAL
    item_id: str  # OPTIONAL
    item_type: Union[str, ItemTypeEnum]  # OPTIONAL
    published_at: str  # OPTIONAL
    sku: str  # OPTIONAL
    title: str  # OPTIONAL
    type_: Union[str, TypeEnum]  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_action(self, value: Union[str, ActionEnum]) -> CatalogChangeInfo:
        self.action = value
        return self

    def with_change_id(self, value: str) -> CatalogChangeInfo:
        self.change_id = value
        return self

    def with_created_at(self, value: str) -> CatalogChangeInfo:
        self.created_at = value
        return self

    def with_namespace(self, value: str) -> CatalogChangeInfo:
        self.namespace = value
        return self

    def with_selected(self, value: bool) -> CatalogChangeInfo:
        self.selected = value
        return self

    def with_status(self, value: Union[str, StatusEnum]) -> CatalogChangeInfo:
        self.status = value
        return self

    def with_store_id(self, value: str) -> CatalogChangeInfo:
        self.store_id = value
        return self

    def with_updated_at(self, value: str) -> CatalogChangeInfo:
        self.updated_at = value
        return self

    def with_category_path(self, value: str) -> CatalogChangeInfo:
        self.category_path = value
        return self

    def with_description(self, value: str) -> CatalogChangeInfo:
        self.description = value
        return self

    def with_item_id(self, value: str) -> CatalogChangeInfo:
        self.item_id = value
        return self

    def with_item_type(self, value: Union[str, ItemTypeEnum]) -> CatalogChangeInfo:
        self.item_type = value
        return self

    def with_published_at(self, value: str) -> CatalogChangeInfo:
        self.published_at = value
        return self

    def with_sku(self, value: str) -> CatalogChangeInfo:
        self.sku = value
        return self

    def with_title(self, value: str) -> CatalogChangeInfo:
        self.title = value
        return self

    def with_type(self, value: Union[str, TypeEnum]) -> CatalogChangeInfo:
        self.type_ = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "action"):
            result["action"] = str(self.action)
        elif include_empty:
            result["action"] = Union[str, ActionEnum]()
        if hasattr(self, "change_id"):
            result["changeId"] = str(self.change_id)
        elif include_empty:
            result["changeId"] = ""
        if hasattr(self, "created_at"):
            result["createdAt"] = str(self.created_at)
        elif include_empty:
            result["createdAt"] = ""
        if hasattr(self, "namespace"):
            result["namespace"] = str(self.namespace)
        elif include_empty:
            result["namespace"] = ""
        if hasattr(self, "selected"):
            result["selected"] = bool(self.selected)
        elif include_empty:
            result["selected"] = False
        if hasattr(self, "status"):
            result["status"] = str(self.status)
        elif include_empty:
            result["status"] = Union[str, StatusEnum]()
        if hasattr(self, "store_id"):
            result["storeId"] = str(self.store_id)
        elif include_empty:
            result["storeId"] = ""
        if hasattr(self, "updated_at"):
            result["updatedAt"] = str(self.updated_at)
        elif include_empty:
            result["updatedAt"] = ""
        if hasattr(self, "category_path"):
            result["categoryPath"] = str(self.category_path)
        elif include_empty:
            result["categoryPath"] = ""
        if hasattr(self, "description"):
            result["description"] = str(self.description)
        elif include_empty:
            result["description"] = ""
        if hasattr(self, "item_id"):
            result["itemId"] = str(self.item_id)
        elif include_empty:
            result["itemId"] = ""
        if hasattr(self, "item_type"):
            result["itemType"] = str(self.item_type)
        elif include_empty:
            result["itemType"] = Union[str, ItemTypeEnum]()
        if hasattr(self, "published_at"):
            result["publishedAt"] = str(self.published_at)
        elif include_empty:
            result["publishedAt"] = ""
        if hasattr(self, "sku"):
            result["sku"] = str(self.sku)
        elif include_empty:
            result["sku"] = ""
        if hasattr(self, "title"):
            result["title"] = str(self.title)
        elif include_empty:
            result["title"] = ""
        if hasattr(self, "type_"):
            result["type"] = str(self.type_)
        elif include_empty:
            result["type"] = Union[str, TypeEnum]()
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        action: Union[str, ActionEnum],
        change_id: str,
        created_at: str,
        namespace: str,
        selected: bool,
        status: Union[str, StatusEnum],
        store_id: str,
        updated_at: str,
        category_path: Optional[str] = None,
        description: Optional[str] = None,
        item_id: Optional[str] = None,
        item_type: Optional[Union[str, ItemTypeEnum]] = None,
        published_at: Optional[str] = None,
        sku: Optional[str] = None,
        title: Optional[str] = None,
        type_: Optional[Union[str, TypeEnum]] = None,
    ) -> CatalogChangeInfo:
        instance = cls()
        instance.action = action
        instance.change_id = change_id
        instance.created_at = created_at
        instance.namespace = namespace
        instance.selected = selected
        instance.status = status
        instance.store_id = store_id
        instance.updated_at = updated_at
        if category_path is not None:
            instance.category_path = category_path
        if description is not None:
            instance.description = description
        if item_id is not None:
            instance.item_id = item_id
        if item_type is not None:
            instance.item_type = item_type
        if published_at is not None:
            instance.published_at = published_at
        if sku is not None:
            instance.sku = sku
        if title is not None:
            instance.title = title
        if type_ is not None:
            instance.type_ = type_
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> CatalogChangeInfo:
        instance = cls()
        if not dict_:
            return instance
        if "action" in dict_ and dict_["action"] is not None:
            instance.action = str(dict_["action"])
        elif include_empty:
            instance.action = Union[str, ActionEnum]()
        if "changeId" in dict_ and dict_["changeId"] is not None:
            instance.change_id = str(dict_["changeId"])
        elif include_empty:
            instance.change_id = ""
        if "createdAt" in dict_ and dict_["createdAt"] is not None:
            instance.created_at = str(dict_["createdAt"])
        elif include_empty:
            instance.created_at = ""
        if "namespace" in dict_ and dict_["namespace"] is not None:
            instance.namespace = str(dict_["namespace"])
        elif include_empty:
            instance.namespace = ""
        if "selected" in dict_ and dict_["selected"] is not None:
            instance.selected = bool(dict_["selected"])
        elif include_empty:
            instance.selected = False
        if "status" in dict_ and dict_["status"] is not None:
            instance.status = str(dict_["status"])
        elif include_empty:
            instance.status = Union[str, StatusEnum]()
        if "storeId" in dict_ and dict_["storeId"] is not None:
            instance.store_id = str(dict_["storeId"])
        elif include_empty:
            instance.store_id = ""
        if "updatedAt" in dict_ and dict_["updatedAt"] is not None:
            instance.updated_at = str(dict_["updatedAt"])
        elif include_empty:
            instance.updated_at = ""
        if "categoryPath" in dict_ and dict_["categoryPath"] is not None:
            instance.category_path = str(dict_["categoryPath"])
        elif include_empty:
            instance.category_path = ""
        if "description" in dict_ and dict_["description"] is not None:
            instance.description = str(dict_["description"])
        elif include_empty:
            instance.description = ""
        if "itemId" in dict_ and dict_["itemId"] is not None:
            instance.item_id = str(dict_["itemId"])
        elif include_empty:
            instance.item_id = ""
        if "itemType" in dict_ and dict_["itemType"] is not None:
            instance.item_type = str(dict_["itemType"])
        elif include_empty:
            instance.item_type = Union[str, ItemTypeEnum]()
        if "publishedAt" in dict_ and dict_["publishedAt"] is not None:
            instance.published_at = str(dict_["publishedAt"])
        elif include_empty:
            instance.published_at = ""
        if "sku" in dict_ and dict_["sku"] is not None:
            instance.sku = str(dict_["sku"])
        elif include_empty:
            instance.sku = ""
        if "title" in dict_ and dict_["title"] is not None:
            instance.title = str(dict_["title"])
        elif include_empty:
            instance.title = ""
        if "type" in dict_ and dict_["type"] is not None:
            instance.type_ = str(dict_["type"])
        elif include_empty:
            instance.type_ = Union[str, TypeEnum]()
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, CatalogChangeInfo]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[CatalogChangeInfo]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        CatalogChangeInfo, List[CatalogChangeInfo], Dict[Any, CatalogChangeInfo]
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "action": "action",
            "changeId": "change_id",
            "createdAt": "created_at",
            "namespace": "namespace",
            "selected": "selected",
            "status": "status",
            "storeId": "store_id",
            "updatedAt": "updated_at",
            "categoryPath": "category_path",
            "description": "description",
            "itemId": "item_id",
            "itemType": "item_type",
            "publishedAt": "published_at",
            "sku": "sku",
            "title": "title",
            "type": "type_",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "action": True,
            "changeId": True,
            "createdAt": True,
            "namespace": True,
            "selected": True,
            "status": True,
            "storeId": True,
            "updatedAt": True,
            "categoryPath": False,
            "description": False,
            "itemId": False,
            "itemType": False,
            "publishedAt": False,
            "sku": False,
            "title": False,
            "type": False,
        }

    @staticmethod
    def get_enum_map() -> Dict[str, List[Any]]:
        return {
            "action": ["CREATE", "DELETE", "UPDATE"],
            "status": ["PUBLISHED", "UNPUBLISHED"],
            "itemType": [
                "APP",
                "BUNDLE",
                "CODE",
                "COINS",
                "EXTENSION",
                "INGAMEITEM",
                "MEDIA",
                "OPTIONBOX",
                "SEASON",
                "SUBSCRIPTION",
            ],
            "type": ["CATEGORY", "ITEM", "STORE"],
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: accelbyte_cloud_py_codegen

"""Auto-generated package that contains models used by the AccelByte Cloud Iam Service."""

__version__ = "5.18.0"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .admin_add_user_role_v4 import AdminAddUserRoleV4
from .admin_bulk_check_valid__17860c import AdminBulkCheckValidUserIDV4
from .admin_create_test_users_v4 import AdminCreateTestUsersV4
from .admin_disable_my_authen_d71ec4 import AdminDisableMyAuthenticatorV4
from .admin_disable_my_backup_727b56 import AdminDisableMyBackupCodesV4
from .admin_disable_user_mfav4 import AdminDisableUserMFAV4
from .admin_download_my_backu_29ee48 import AdminDownloadMyBackupCodesV4
from .admin_enable_my_authent_263fb3 import AdminEnableMyAuthenticatorV4
from .admin_enable_my_backup__1f7c71 import AdminEnableMyBackupCodesV4
from .admin_generate_my_authe_b02d34 import AdminGenerateMyAuthenticatorKeyV4
from .admin_generate_my_backu_fdd3aa import AdminGenerateMyBackupCodesV4
from .admin_get_my_backup_codes_v4 import AdminGetMyBackupCodesV4
from .admin_get_my_enabled_fa_206f77 import AdminGetMyEnabledFactorsV4
from .admin_invite_user_v4 import AdminInviteUserV4
from .admin_list_user_roles_v4 import AdminListUserRolesV4
from .admin_make_factor_my_de_88728e import AdminMakeFactorMyDefaultV4
from .admin_remove_user_role_v4 import AdminRemoveUserRoleV4
from .admin_update_my_user_v4 import AdminUpdateMyUserV4
from .admin_update_user_email_3f25ce import AdminUpdateUserEmailAddressV4
from .admin_update_user_role_v4 import AdminUpdateUserRoleV4
from .admin_update_user_v4 import AdminUpdateUserV4
from .create_user_from_invitation_v4 import CreateUserFromInvitationV4
from .public_create_test_user_v4 import PublicCreateTestUserV4
from .public_create_user_v4 import PublicCreateUserV4
from .public_disable_my_authe_beac3e import PublicDisableMyAuthenticatorV4
from .public_disable_my_backu_92ead1 import PublicDisableMyBackupCodesV4
from .public_download_my_back_3f3640 import PublicDownloadMyBackupCodesV4
from .public_enable_my_authen_556050 import PublicEnableMyAuthenticatorV4
from .public_enable_my_backup_e6b7c1 import PublicEnableMyBackupCodesV4
from .public_generate_my_auth_17372a import PublicGenerateMyAuthenticatorKeyV4
from .public_generate_my_back_da569a import PublicGenerateMyBackupCodesV4
from .public_get_my_backup_codes_v4 import PublicGetMyBackupCodesV4
from .public_get_my_enabled_f_a93b10 import PublicGetMyEnabledFactorsV4
from .public_make_factor_my_d_4f4f01 import PublicMakeFactorMyDefaultV4
from .public_remove_trusted_d_78cd8f import PublicRemoveTrustedDeviceV4
from .public_update_user_emai_2d6478 import PublicUpdateUserEmailAddressV4
from .public_update_user_v4 import PublicUpdateUserV4
from .public_upgrade_headless_966239 import PublicUpgradeHeadlessAccountV4
from .public_upgrade_headless_a902b1 import (
    PublicUpgradeHeadlessAccountWithVerificationCodeV4,
)



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: accelbyte_cloud_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import HeaderStr
from ....core import get_namespace as get_services_namespace
from ....core import run_request
from ....core import run_request_async
from ....core import same_doc_as

from ..models import ModelsCreateGroupConfigurationRequestV1
from ..models import ModelsCreateGroupConfigurationResponseV1
from ..models import ModelsGetGroupConfigurationResponseV1
from ..models import ModelsListConfigurationResponseV1
from ..models import ModelsUpdateGroupConfigurationGlobalRulesRequestV1
from ..models import ModelsUpdateGroupConfigurationRequestV1
from ..models import ModelsUpdateGroupConfigurationResponseV1
from ..models import ResponseErrorResponse

from ..operations.configuration import CreateGroupConfigurationAdminV1
from ..operations.configuration import DeleteGroupConfigurationGlobalRuleAdminV1
from ..operations.configuration import DeleteGroupConfigurationV1
from ..operations.configuration import GetGroupConfigurationAdminV1
from ..operations.configuration import InitiateGroupConfigurationAdminV1
from ..operations.configuration import ListGroupConfigurationAdminV1
from ..operations.configuration import UpdateGroupConfigurationAdminV1
from ..operations.configuration import UpdateGroupConfigurationGlobalRuleAdminV1


@same_doc_as(CreateGroupConfigurationAdminV1)
def create_group_configuration_admin_v1(
    body: ModelsCreateGroupConfigurationRequestV1,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = CreateGroupConfigurationAdminV1.create(
        body=body,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(CreateGroupConfigurationAdminV1)
async def create_group_configuration_admin_v1_async(
    body: ModelsCreateGroupConfigurationRequestV1,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = CreateGroupConfigurationAdminV1.create(
        body=body,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(DeleteGroupConfigurationGlobalRuleAdminV1)
def delete_group_configuration_global_rule_admin_v1(
    allowed_action: str,
    configuration_code: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = DeleteGroupConfigurationGlobalRuleAdminV1.create(
        allowed_action=allowed_action,
        configuration_code=configuration_code,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(DeleteGroupConfigurationGlobalRuleAdminV1)
async def delete_group_configuration_global_rule_admin_v1_async(
    allowed_action: str,
    configuration_code: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = DeleteGroupConfigurationGlobalRuleAdminV1.create(
        allowed_action=allowed_action,
        configuration_code=configuration_code,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(DeleteGroupConfigurationV1)
def delete_group_configuration_v1(
    configuration_code: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = DeleteGroupConfigurationV1.create(
        configuration_code=configuration_code,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(DeleteGroupConfigurationV1)
async def delete_group_configuration_v1_async(
    configuration_code: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = DeleteGroupConfigurationV1.create(
        configuration_code=configuration_code,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(GetGroupConfigurationAdminV1)
def get_group_configuration_admin_v1(
    configuration_code: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetGroupConfigurationAdminV1.create(
        configuration_code=configuration_code,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GetGroupConfigurationAdminV1)
async def get_group_configuration_admin_v1_async(
    configuration_code: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetGroupConfigurationAdminV1.create(
        configuration_code=configuration_code,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(InitiateGroupConfigurationAdminV1)
def initiate_group_configuration_admin_v1(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = InitiateGroupConfigurationAdminV1.create(
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(InitiateGroupConfigurationAdminV1)
async def initiate_group_configuration_admin_v1_async(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = InitiateGroupConfigurationAdminV1.create(
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(ListGroupConfigurationAdminV1)
def list_group_configuration_admin_v1(
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = ListGroupConfigurationAdminV1.create(
        limit=limit,
        offset=offset,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(ListGroupConfigurationAdminV1)
async def list_group_configuration_admin_v1_async(
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = ListGroupConfigurationAdminV1.create(
        limit=limit,
        offset=offset,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(UpdateGroupConfigurationAdminV1)
def update_group_configuration_admin_v1(
    body: ModelsUpdateGroupConfigurationRequestV1,
    configuration_code: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = UpdateGroupConfigurationAdminV1.create(
        body=body,
        configuration_code=configuration_code,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(UpdateGroupConfigurationAdminV1)
async def update_group_configuration_admin_v1_async(
    body: ModelsUpdateGroupConfigurationRequestV1,
    configuration_code: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = UpdateGroupConfigurationAdminV1.create(
        body=body,
        configuration_code=configuration_code,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(UpdateGroupConfigurationGlobalRuleAdminV1)
def update_group_configuration_global_rule_admin_v1(
    allowed_action: str,
    body: ModelsUpdateGroupConfigurationGlobalRulesRequestV1,
    configuration_code: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = UpdateGroupConfigurationGlobalRuleAdminV1.create(
        allowed_action=allowed_action,
        body=body,
        configuration_code=configuration_code,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(UpdateGroupConfigurationGlobalRuleAdminV1)
async def update_group_configuration_global_rule_admin_v1_async(
    allowed_action: str,
    body: ModelsUpdateGroupConfigurationGlobalRulesRequestV1,
    configuration_code: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = UpdateGroupConfigurationGlobalRuleAdminV1.create(
        allowed_action=allowed_action,
        body=body,
        configuration_code=configuration_code,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: accelbyte_cloud_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import HeaderStr
from ....core import get_namespace as get_services_namespace
from ....core import run_request
from ....core import run_request_async
from ....core import same_doc_as

from ..models import AddCountryGroupRequest
from ..models import AddCountryGroupResponse
from ..models import CountryGroupObject
from ..models import CountryObject
from ..models import ErrorEntity
from ..models import RetrieveCountryGroupResponse
from ..models import RetrieveTimeResponse
from ..models import UpdateCountryGroupRequest
from ..models import ValidationErrorEntity

from ..operations.misc import AddCountryGroup
from ..operations.misc import DeleteCountryGroup
from ..operations.misc import GetCountries
from ..operations.misc import GetCountryGroups
from ..operations.misc import GetLanguages
from ..operations.misc import GetTimeZones
from ..operations.misc import PublicGetCountries
from ..operations.misc import PublicGetLanguages
from ..operations.misc import PublicGetTime
from ..operations.misc import PublicGetTimeZones
from ..operations.misc import UpdateCountryGroup


@same_doc_as(AddCountryGroup)
def add_country_group(
    body: Optional[AddCountryGroupRequest] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AddCountryGroup.create(
        body=body,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AddCountryGroup)
async def add_country_group_async(
    body: Optional[AddCountryGroupRequest] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AddCountryGroup.create(
        body=body,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(DeleteCountryGroup)
def delete_country_group(
    country_group_code: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = DeleteCountryGroup.create(
        country_group_code=country_group_code,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(DeleteCountryGroup)
async def delete_country_group_async(
    country_group_code: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = DeleteCountryGroup.create(
        country_group_code=country_group_code,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(GetCountries)
def get_countries(
    lang: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetCountries.create(
        lang=lang,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GetCountries)
async def get_countries_async(
    lang: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetCountries.create(
        lang=lang,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(GetCountryGroups)
def get_country_groups(
    group_code: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetCountryGroups.create(
        group_code=group_code,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GetCountryGroups)
async def get_country_groups_async(
    group_code: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetCountryGroups.create(
        group_code=group_code,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(GetLanguages)
def get_languages(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetLanguages.create(
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GetLanguages)
async def get_languages_async(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetLanguages.create(
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(GetTimeZones)
def get_time_zones(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetTimeZones.create(
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GetTimeZones)
async def get_time_zones_async(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetTimeZones.create(
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(PublicGetCountries)
def public_get_countries(
    lang: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = PublicGetCountries.create(
        lang=lang,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(PublicGetCountries)
async def public_get_countries_async(
    lang: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = PublicGetCountries.create(
        lang=lang,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(PublicGetLanguages)
def public_get_languages(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = PublicGetLanguages.create(
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(PublicGetLanguages)
async def public_get_languages_async(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = PublicGetLanguages.create(
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(PublicGetTime)
def public_get_time(x_additional_headers: Optional[Dict[str, str]] = None, **kwargs):
    request = PublicGetTime.create()
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(PublicGetTime)
async def public_get_time_async(
    x_additional_headers: Optional[Dict[str, str]] = None, **kwargs
):
    request = PublicGetTime.create()
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(PublicGetTimeZones)
def public_get_time_zones(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = PublicGetTimeZones.create(
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(PublicGetTimeZones)
async def public_get_time_zones_async(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = PublicGetTimeZones.create(
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(UpdateCountryGroup)
def update_country_group(
    country_group_code: str,
    body: Optional[UpdateCountryGroupRequest] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = UpdateCountryGroup.create(
        country_group_code=country_group_code,
        body=body,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(UpdateCountryGroup)
async def update_country_group_async(
    country_group_code: str,
    body: Optional[UpdateCountryGroupRequest] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = UpdateCountryGroup.create(
        country_group_code=country_group_code,
        body=body,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )
